package de.hsrm.jakartaee.knauf.statelessmaven.web.test;

import java.io.File;
import java.net.URL;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.RunAsClient;
import org.jboss.arquillian.drone.api.annotation.Drone;
import org.jboss.arquillian.junit5.ArquillianExtension;
import org.jboss.arquillian.test.api.ArquillianResource;
import org.jboss.shrinkwrap.api.Archive;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.importer.ZipImporter;
import org.jboss.shrinkwrap.api.spec.EnterpriseArchive;
import org.jboss.shrinkwrap.api.spec.JavaArchive;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;

@ExtendWith(ArquillianExtension.class)
@RunAsClient
public class ServletIT
{
    @Deployment
    public static Archive<?> getEarArchive()
    {
        EnterpriseArchive ear = ShrinkWrap.create(EnterpriseArchive.class, "StatelessMaven-ear.ear");
        
        File f = new File("../ejb/target/StatelessMaven-ejb.jar");
        JavaArchive ejbJar = ShrinkWrap.create(ZipImporter.class, "StatelessMaven-ejb.jar").
              importFrom(f).as(JavaArchive.class) ;
        ear.addAsModule(ejbJar);
         
        
        f = new File("../web/target/StatelessMaven-web.war");
        WebArchive war = ShrinkWrap.create(ZipImporter.class, "StatelessMaven-web.war").
               importFrom(f).as(WebArchive.class) ;
        ear.addAsModule(war);
        
        war.addPackage("de.hsrm.jakartaee.knauf.statelessmaven.web.test");
          
        //Export der EAR-Datei für Diagnosezwecke:
        //ear.as(org.jboss.shrinkwrap.api.exporter.ZipExporter.class).exportTo(new File("c:\\temp\\test.ear"), true);
        
        return ear;
    }

    @Drone
    private WebDriver browser;
    
    @ArquillianResource()
    private URL deploymentUrl;

    @Test
    public final void browserTest() throws Exception
    {
        System.out.println("Testing client website ... " + deploymentUrl);
        
        //Zur Startseite navigieren:
        browser.get(deploymentUrl.toString() + "servlet/GeometricModelServlet");
        
        //Formular ausfüllen:
        browser.findElement(By.name("a")).sendKeys("7");
        browser.findElement(By.name("b")).sendKeys("8");
        browser.findElement(By.name("c")).sendKeys("9");
        //Formular abschicken:
        browser.findElement(By.name("submit")).click();

        //Ergebnisse auswerten:
        String volume = browser.findElement(By.name("volume")).getText();
        Assertions.assertEquals("504.0", volume);
        
        String surface = browser.findElement(By.name("surface")).getText();
        Assertions.assertEquals("382.0", surface);
    }
}